#
# spec file for package php-ssh2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_name    ssh2

%define flavor php8%{nil}
%if "%{flavor}" == "" || (0%{?suse_version} >= 1550 && "%{flavor}" == "php7")
%define php_name php
ExclusiveArch:  do-not-build
%else
%define php_name %{flavor}
%endif
%if 0%{?suse_version} <= 1500
%define php_extdir  %(%{__php_config} --extension-dir)
%define php_cfgdir  %{_sysconfdir}/%{php_name}/conf.d
%endif

Name:           %{php_name}-%{pkg_name}
Version:        1.4.1
Release:        1.3
Summary:        PHP bindings for the libssh2 library
License:        PHP-3.01
Group:          Productivity/Networking/Web/Servers
URL:            https://pecl.php.net/package/%{pkg_name}
Source:         https://pecl.php.net/get/%{pkg_name}-%{version}.tgz
BuildRequires:  %{php_name}-devel
BuildRequires:  libssh2-devel
Provides:       php-%{pkg_name} = %{version}
Requires:       php(api) = %{php_core_api}
Requires:       php(zend-abi) = %{php_zend_api}

%description
This package provides PHP bindings for the libssh2 library

%prep
%setup -q -n %{pkg_name}-%{version}

%build
export CFLAGS="%{optflags} -fvisibility=hidden"
%{__phpize}
%configure
%make_build

%install
%make_install INSTALL_ROOT=%{buildroot}
mkdir -p %{buildroot}%{php_cfgdir}
cat > %{buildroot}%{php_cfgdir}/%{pkg_name}.ini << EOF
; comment out next line to disable %{pkg_name} extension in php
extension = %{pkg_name}.so
EOF

%check
%make_build test PHP_EXECUTABLE=%{__php} NO_INTERACTION=1

%files
%doc README.md
%license LICENSE
%config(noreplace) %{php_cfgdir}/%{pkg_name}.ini
%{php_extdir}/%{pkg_name}.so

%changelog
* Tue Feb 13 2024 Arjen de Korte <suse+build@de-korte.org>
- Update to 1.4.1:
  * End zend_function_entry ssh2_functions list with PHP_FE_END
  * Remove implicit switch-case fallthrough
  * Windows build setup with GitHub Actions
* Sun May  7 2023 Arjen de Korte <suse+build@de-korte.org>
- Update to 1.4:
  * Add ssh2_shell_resize function
  * Add ssh2_auth_pubkey to allow public and private keys as strings
* Sat Dec 10 2022 Arjen de Korte <suse+build@de-korte.org>
- Remove php7 build for Tumbleweed (PHP 7.4 has reached EOL)
* Sat Dec 25 2021 Arjen de Korte <suse+build@de-korte.org>
- Initial release version 1.3.1
